@@ -13,7 +13,7 @@ our @ISA = qw(Exporter);
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-# This allows declaration	use NKTI::enkripsi::enkripsi ':all';
+# This allows declaration	use NKTI::general ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw( cetak cetak_r ) ]);
@@ -22,7 +22,7 @@ our @EXPORT = qw(cetak cetak_r);
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Create Subroutine for Get OS Server Information :
 # ------------------------------------------------------------------------
@@ -566,8 +566,16 @@ sub cetak_r {
 
 1;
 __END__
+=head1 NAME
+
+    NKTI::general - The Part of NKTIweb The Simple Web Framework
+
+=head1 VERSION
+
+    This document describes NKTI::general version 0.06.
+
 =head1 AUTHOR
-    Achmad Yusri Afandi, (linuxer08@gmail.com)
+    Achmad Yusri Afandi, (linuxer08@gmail.com).
 
 =head1 COPYRIGHT AND LICENSE
     Copyright (c) 2016, Achmad Yusri Afandi, All Rights reserved.
