@@ -8,7 +8,7 @@ use Data::Dumper;
 
 # Define Version :
 # ---------------------------------------------------------------- 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Subroutine for Error Handling MySQL Connection :
 # ------------------------------------------------------------------------
@@ -24,7 +24,11 @@ our $VERSION = '0.05';
     
 =cut
 sub errconn {
-	
+
+	# Define parameter subroutine :
+	# ----------------------------------------------------------------
+	my $self = shift;
+
 	# Define array for place error DBMS Connection :
 	# ----------------------------------------------------------------
 	my @data = ();
